nbxmpp.protocol.Presence

Package nbxmpp :: Module protocol :: Class Presence |
[hide private]
[frames] | no frames]

# Class Presence

source code

Instance Methods | [hide private]
__init__(self, to=None, typ=None, priority=None, show=None, status=None, attrs=`{``}`, frm=None, timestamp=None, payload=`[``]`, xmlns=`'``jabber:client``'`, node=None) You can specify recipient, type of message, priority, show and status values any additional attributes, sender of the presence, timestamp, any additional payload (f.e. jabber:x:delay element) and namespace in one go. Alternatively you can pass in the other XML object as the 'node' parameted to replicate it as presence | source code
getPriority(self) Return the priority of the message | source code
getShow(self) Return the show value of the message | source code
getStatus(self) Return the status string of the message | source code
setPriority(self, val) Set the priority of the message | source code
setShow(self, val) Set the show value of the message | source code
setStatus(self, val) Set the status string of the message | source code
_muc_getItemAttr(self, tag, attr) | source code
_muc_getSubTagDataAttr(self, tag, attr) | source code
getRole(self) Return the presence role (for groupchat) | source code
getAffiliation(self) Return the presence affiliation (for groupchat) | source code
getNewNick(self) Return the status code of the presence (for groupchat) | source code
getJid(self) Return the presence jid (for groupchat) | source code
getReason(self) Returns the reason of the presence (for groupchat) | source code
getActor(self) Return the reason of the presence (for groupchat) | source code
getStatusCode(self) Return the status code of the presence (for groupchat) | source code
Inherited from `Protocol`: `__setitem__`, `getError`, `getErrorCode`, `getErrorMsg`, `getFrom`, `getID`, `getProperties`, `getStatusConditions`, `getTimestamp`, `getTimestamp2`, `getTo`, `getType`, `setError`, `setFrom`, `setID`, `setTimestamp`, `setTo`, `setType` Inherited from `simplexml.Node`: `__contains__`, `__delitem__`, `__getattr__`, `__getitem__`, `__str__`, `addChild`, `addData`, `clearData`, `delAttr`, `delChild`, `getAttr`, `getAttrs`, `getChildren`, `getData`, `getName`, `getNamespace`, `getParent`, `getPayload`, `getTag`, `getTagAttr`, `getTagData`, `getTags`, `has_attr`, `iterTags`, `lookup_nsp`, `setAttr`, `setData`, `setName`, `setNamespace`, `setParent`, `setPayload`, `setTag`, `setTagAttr`, `setTagData` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `simplexml.Node`: `FORCE_NODE_RECREATION`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, to=None, typ=None, priority=None, show=None, status=None, attrs=`{``}`, frm=None, timestamp=None, payload=`[``]`, xmlns=`'``jabber:client``'`, node=None) (Constructor) | source code
You can specify recipient, type of message, priority, show and status values any additional attributes, sender of the presence, timestamp, any additional payload (f.e. jabber:x:delay element) and namespace in one go. Alternatively you can pass in the other XML object as the 'node' parameted to replicate it as presence Overrides: object.__init__

### getPriority(self) | source code
Return the priority of the message

### getShow(self) | source code
Return the show value of the message

### getStatus(self) | source code
Return the status string of the message

### setPriority(self, val) | source code
Set the priority of the message

### setShow(self, val) | source code
Set the show value of the message

### setStatus(self, val) | source code
Set the status string of the message

### _muc_getItemAttr(self, tag, attr) | source code

### _muc_getSubTagDataAttr(self, tag, attr) | source code

### getRole(self) | source code
Return the presence role (for groupchat)

### getAffiliation(self) | source code
Return the presence affiliation (for groupchat)

### getNewNick(self) | source code
Return the status code of the presence (for groupchat)

### getJid(self) | source code
Return the presence jid (for groupchat)

### getReason(self) | source code
Returns the reason of the presence (for groupchat)

### getActor(self) | source code
Return the reason of the presence (for groupchat)

### getStatusCode(self) | source code
Return the status code of the presence (for groupchat)